[firstboot] Add the admin user to dialout group (#771918)

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

 



---
 modules/create_user.py |    5 ++++-
 1 files changed, 4 insertions(+), 1 deletions(-)

diff --git a/modules/create_user.py b/modules/create_user.py
index 4f1ebab..b9d07c6 100644
--- a/modules/create_user.py
+++ b/modules/create_user.py
@@ -279,11 +279,14 @@ class moduleClass(Module):
 
         self.admin.setpassUser(userEnt, self.passwordEntry.get_text(), 0)
 
         # add user to wheel group
         if self.is_admin.get_active():
             wheelEnt = self.admin.lookupGroupByName("wheel")
             wheelEnt.add(libuser.MEMBERNAME, username)
             self.admin.modifyGroup(wheelEnt)
+            dialoutEnt = self.admin.lookupGroupByName("dialout")
+            dialoutEnt.add(libuser.MEMBERNAME, username)
+            self.admin.modifyGroup(dialoutEnt)
 
         return RESULT_SUCCESS
 
@@ -279,11 +279,14 @@ class moduleClass(Module):
         self.admin.setpassUser(userEnt, self.passwordEntry.get_text(), 0)
 
-        # add user to wheel group
+        # add user to wheel and dialout group
         if self.is_admin.get_active():
             wheelEnt = self.admin.lookupGroupByName("wheel")
-- 
1.7.5.4

_______________________________________________
Anaconda-devel-list mailing list
Anaconda-devel-list@xxxxxxxxxx
https://www.redhat.com/mailman/listinfo/anaconda-devel-list


[Index of Archives]     [Kickstart]     [Fedora Users]     [Fedora Legacy List]     [Fedora Maintainers]     [Fedora Desktop]     [Fedora SELinux]     [Big List of Linux Books]     [Yosemite News]     [Yosemite Photos]     [KDE Users]     [Fedora Tools]
  Powered by Linux